@@ -9,8 +9,8 @@ def print_info() -> None:
     Print package info to stdout.
     """
     print(
-        "Type annotations for boto3.WorkSpacesWeb 1.23.0\nVersion:         1.23.0.post1\nBuilder"
-        " version: 7.5.14\nDocs:           "
+        "Type annotations for boto3.WorkSpacesWeb 1.23.1\nVersion:         1.23.1\nBuilder version:"
+        " 7.6.0\nDocs:           "
         " https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web//\nBoto3 docs:     "
         " https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces-web.html#WorkSpacesWeb\nOther"
         " services:  https://pypi.org/project/boto3-stubs/\nChangelog:      "
@@ -22,7 +22,7 @@ def print_version() -> None:
     """
     Print package version to stdout.
     """
-    print("1.23.0.post1")
+    print("1.23.1")
 
 
 def main() -> None:
