@@ -150,7 +150,7 @@ class WorkSpacesWebClient(BaseClient):
         additionalEncryptionContext: Mapping[str, str] = ...,
         clientToken: str = ...,
         customerManagedKey: str = ...,
-        tags: Sequence["TagTypeDef"] = ...
+        tags: Sequence[TagTypeDef] = ...
     ) -> CreateBrowserSettingsResponseTypeDef:
         """
         Creates a browser settings resource that can be associated with a web portal.
@@ -182,7 +182,7 @@ class WorkSpacesWebClient(BaseClient):
         subnetIds: Sequence[str],
         vpcId: str,
         clientToken: str = ...,
-        tags: Sequence["TagTypeDef"] = ...
+        tags: Sequence[TagTypeDef] = ...
     ) -> CreateNetworkSettingsResponseTypeDef:
         """
         Creates a network settings resource that can be associated with a web portal.
@@ -198,7 +198,7 @@ class WorkSpacesWebClient(BaseClient):
         clientToken: str = ...,
         customerManagedKey: str = ...,
         displayName: str = ...,
-        tags: Sequence["TagTypeDef"] = ...
+        tags: Sequence[TagTypeDef] = ...
     ) -> CreatePortalResponseTypeDef:
         """
         Creates a web portal.
@@ -212,7 +212,7 @@ class WorkSpacesWebClient(BaseClient):
         *,
         certificateList: Sequence[Union[str, bytes, IO[Any], StreamingBody]],
         clientToken: str = ...,
-        tags: Sequence["TagTypeDef"] = ...
+        tags: Sequence[TagTypeDef] = ...
     ) -> CreateTrustStoreResponseTypeDef:
         """
         Creates a trust store that can be associated with a web portal.
@@ -230,7 +230,9 @@ class WorkSpacesWebClient(BaseClient):
         printAllowed: EnabledTypeType,
         uploadAllowed: EnabledTypeType,
         clientToken: str = ...,
-        tags: Sequence["TagTypeDef"] = ...
+        disconnectTimeoutInMinutes: int = ...,
+        idleDisconnectTimeoutInMinutes: int = ...,
+        tags: Sequence[TagTypeDef] = ...
     ) -> CreateUserSettingsResponseTypeDef:
         """
         Creates a user settings resource that can be associated with a web portal.
@@ -482,7 +484,7 @@ class WorkSpacesWebClient(BaseClient):
         """
 
     def tag_resource(
-        self, *, resourceArn: str, tags: Sequence["TagTypeDef"], clientToken: str = ...
+        self, *, resourceArn: str, tags: Sequence[TagTypeDef], clientToken: str = ...
     ) -> Dict[str, Any]:
         """
         Adds or overwrites one or more tags for the specified resource.
@@ -572,7 +574,9 @@ class WorkSpacesWebClient(BaseClient):
         userSettingsArn: str,
         clientToken: str = ...,
         copyAllowed: EnabledTypeType = ...,
+        disconnectTimeoutInMinutes: int = ...,
         downloadAllowed: EnabledTypeType = ...,
+        idleDisconnectTimeoutInMinutes: int = ...,
         pasteAllowed: EnabledTypeType = ...,
         printAllowed: EnabledTypeType = ...,
         uploadAllowed: EnabledTypeType = ...
